winhide

package
v1.0.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 21, 2026 License: Apache-2.0 Imports: 2 Imported by: 0

Documentation

Overview

Package winhide provides a cross-platform helper to hide console windows when spawning external commands. On Windows it sets HideWindow; on other platforms it is a no-op.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Cmd

func Cmd(cmd *exec.Cmd)

Cmd configures cmd so that no console window is shown. On Windows it sets HideWindow; on other platforms it does nothing.

func Command

func Command(name string, arg ...string) *exec.Cmd

Command is like exec.Command but also hides the console window on Windows.

func CommandContext

func CommandContext(ctx context.Context, name string, arg ...string) *exec.Cmd

CommandContext is like exec.CommandContext but also hides the console window on Windows. Use it as a drop-in replacement for exec.CommandContext when spawning external commands that should not flash a terminal window.

Types

This section is empty.

Jump to